==> siga.copmoz.ac.mz_02_56.zip: storage/framework/views/eebac5bdc83e96fc8eb6b03a49b29d5b.php <==
<div>
    <div class="page-sidebar">
        <ul class="list-unstyled accordion-menu">
            <li class="sidebar-title">
                Menu
            </li>
            <li>
                <a href="<?php echo e(route('admin.home')); ?>"><i data-feather="home"></i>Painel de Controle</a>
            </li>
            <li class="sidebar-title">
                Operações
            </li>
            <li>
                <a href="#"><i data-feather="user"></i>Conta<i class="fas fa-chevron-right dropdown-icon"></i></a>
                <ul class="">
                    <li><a href="<?php echo e(route('admin.profile')); ?>"><i class="far fa-circle"></i>Perfil</a></li>
                    <li><a href="<?php echo e(route('admin.credentials')); ?>"><i class="far fa-circle"></i>Credenciais</a></li>
                </ul>
            </li>
 


            <?php if($user->role == 2): ?>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.list.classes.teacher')); ?>"><i class="far fa-circle"></i>Listar</a>
            
                    </ul>
                </li>
                
                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral (D)</a>
                </li>

                

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>





            <?php elseif($user->role == 1): ?>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">

                        <li><a href="<?php echo e(route('admin.list.paid.students')); ?>"><i class="far fa-circle"></i>Regulares</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.unpaid.students')); ?>"><i
                                    class="far fa-circle"></i>Irregulares</a></li>
                    </ul>
                </li>

                




            <?php elseif($user->role == 3): ?>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.class')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.classes.teacher')); ?>"><i class="far fa-circle"></i>Listar</a>
                        </li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Professores<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.teacher')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.add.teacher.subject')); ?>"><i class="far fa-circle"></i>Atribuir
                                Disciplina</a></li>
                        <li><a href="<?php echo e(route('admin.list.teachers')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.student')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.students')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Matrizes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.download')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.downloads')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>

                <li>
                    <a href="#"><i data-feather="users"></i>Comunicados<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class=""><li><a href="<?php echo e(route('admin.add.notification')); ?>"><i class="far fa-circle"></i>Enviar notificação</a></li>
                        <li><a href="<?php echo e(route('admin.add.sms')); ?>"><i class="far fa-circle"></i>Enviar SMS</a></li>
                        <li><a href="<?php echo e(route('admin.sms')); ?>"><i class="far fa-circle"></i>Listar SMS</a></li>

                        <li><a href="<?php echo e(route('admin.add.notice')); ?>"><i class="far fa-circle"></i>Adicionar comunicado</a></li>
                        <li><a href="<?php echo e(route('admin.notice')); ?>"><i class="far fa-circle"></i>Listar comunicados</a></li>
                    </ul>
                </li>
                
                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral
                        (D)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.combine.report')); ?>"><i data-feather="file-text"></i>Relatório
                        trimestral (T)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>
            <?php else: ?>
                <li>
                    <a href="#"><i data-feather="users"></i>Staff<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.admin')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.admins')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Professores<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.teacher.subject')); ?>"><i class="far fa-circle"></i>Atribuir
                                Disciplina</a></li>
                        <li><a href="<?php echo e(route('admin.list.teachers')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.class')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.classes')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Disciplina<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.subject')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.subjects')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.student')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.students')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                        <li><a href="<?php echo e(route('admin.list.paid.students')); ?>"><i
                                    class="far fa-circle"></i>Regulares</a></li>
                        <li><a href="<?php echo e(route('admin.list.unpaid.students')); ?>"><i
                                    class="far fa-circle"></i>Irregulares</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Matrizes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.download')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.downloads')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Conf. de Pgmto<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.payment')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.payments')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Comunicados<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                    <li>
                        <a href="<?php echo e(route('admin.add.notification')); ?>"><i class="far fa-circle"></i>Enviar notificação</a></li>
                        <li><a href="<?php echo e(route('admin.add.sms')); ?>"><i class="far fa-circle"></i>Enviar SMS</a></li> 
                        <li><a href="<?php echo e(route('admin.sms')); ?>"><i class="far fa-circle"></i>Listar SMS</a></li>
                        <li><a href="<?php echo e(route('admin.add.notice')); ?>"><i class="far fa-circle"></i>Adicionar comunicado</a></li>
                        <li><a href="<?php echo e(route('admin.notice')); ?>"><i class="far fa-circle"></i>Listar comunicados</a></li>
                    </ul>
                </li>


				<li class="sidebar-title">
                Biblioteca digital
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Categoria<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.category')); ?>"><i class="far fa-circle"></i>Adiciconar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.categories')); ?>"><i class="far fa-circle"></i>Listar</a>
                        </li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Livros<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.book')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.books')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Capítulos de livro<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.chapter')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.chapters')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>



                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral
                        (D)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.combine.report')); ?>"><i data-feather="file-text"></i>Relatório
                        trimestral (T)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>
            <?php endif; ?>
            <li>
                <a href="#" wire:click="logout"><i data-feather="log-out"></i>Sair</a>
            </li>
        </ul>
    </div>
</div>
<?php /**PATH /home/1165120.cloudwaysapps.com/ttmjqktapb/public_html/resources/views/livewire/admin/inc/sidebar.blade.php ENDPATH**/ ?>

==> siga.copmoz.ac.mz_19_10_2025.zip: storage/framework/views/eebac5bdc83e96fc8eb6b03a49b29d5b.php <==
<div>
    <div class="page-sidebar">
        <ul class="list-unstyled accordion-menu">
            <li class="sidebar-title">
                Menu
            </li>
            <li>
                <a href="<?php echo e(route('admin.home')); ?>"><i data-feather="home"></i>Painel de Controle</a>
            </li>
            <li class="sidebar-title">
                Operações
            </li>
            <li>
                <a href="#"><i data-feather="user"></i>Conta<i class="fas fa-chevron-right dropdown-icon"></i></a>
                <ul class="">
                    <li><a href="<?php echo e(route('admin.profile')); ?>"><i class="far fa-circle"></i>Perfil</a></li>
                    <li><a href="<?php echo e(route('admin.credentials')); ?>"><i class="far fa-circle"></i>Credenciais</a></li>
                </ul>
            </li>



            <?php if($user->role == 2): ?>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.list.classes.teacher')); ?>"><i class="far fa-circle"></i>Listar</a>

                    </ul>
                </li>

                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral (D)</a>
                </li>

                

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>
            <?php elseif($user->role == 1): ?>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">

                        <li><a href="<?php echo e(route('admin.list.paid.students')); ?>"><i class="far fa-circle"></i>Regulares</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.unpaid.students')); ?>"><i
                                    class="far fa-circle"></i>Irregulares</a></li>
                    </ul>
                </li>
            <?php elseif($user->role == 3): ?>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.class')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.classes.teacher')); ?>"><i class="far fa-circle"></i>Listar</a>
                        </li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Professores<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.teacher')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.add.teacher.subject')); ?>"><i class="far fa-circle"></i>Atribuir
                                Disciplina</a></li>
                        <li><a href="<?php echo e(route('teachers.assignments.view')); ?>"><i class="far fa-circle"></i>Gerenciar Atribuições</a></li>
                        <li><a href="<?php echo e(route('admin.list.teachers')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.student')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.students')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Matrizes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.download')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.downloads')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>

                <li>
                    <a href="#"><i data-feather="users"></i>Comunicados<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.notification')); ?>"><i class="far fa-circle"></i>Enviar
                                notificação</a></li>
                        <li><a href="<?php echo e(route('admin.add.sms')); ?>"><i class="far fa-circle"></i>Enviar SMS</a></li>
                        <li><a href="<?php echo e(route('admin.sms')); ?>"><i class="far fa-circle"></i>Listar SMS</a></li>

                        <li><a href="<?php echo e(route('admin.add.notice')); ?>"><i class="far fa-circle"></i>Adicionar
                                comunicado</a></li>
                        <li><a href="<?php echo e(route('admin.notice')); ?>"><i class="far fa-circle"></i>Listar comunicados</a>
                        </li>
                    </ul>
                </li>

                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral
                        (D)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.combine.report')); ?>"><i data-feather="file-text"></i>Relatório
                        trimestral (T)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>
            <?php else: ?>
                <li>
                    <a href="#"><i data-feather="users"></i>Staff<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.admin')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.admins')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Professores<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.teacher.subject')); ?>"><i class="far fa-circle"></i>Atribuir
                                Disciplina</a></li>
                        <li><a href="<?php echo e(route('admin.list.teachers')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Turma<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.class')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.classes')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Disciplina<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.subject')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.subjects')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Estudantes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.student')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.students')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                        <li><a href="<?php echo e(route('admin.list.paid.students')); ?>"><i
                                    class="far fa-circle"></i>Regulares</a></li>
                        <li><a href="<?php echo e(route('admin.list.unpaid.students')); ?>"><i
                                    class="far fa-circle"></i>Irregulares</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Matrizes<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.download')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.downloads')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Conf. de Pgmto<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.payment')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.payments')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>

                <li>
                    <a href="#"><i data-feather="users"></i>Comunicados<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li>
                            <a href="<?php echo e(route('admin.add.notification')); ?>"><i class="far fa-circle"></i>Enviar
                                notificação</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.add.sms')); ?>"><i class="far fa-circle"></i>Enviar SMS</a></li>
                        <li><a href="<?php echo e(route('admin.sms')); ?>"><i class="far fa-circle"></i>Listar SMS</a></li>
                        <li><a href="<?php echo e(route('admin.add.notice')); ?>"><i class="far fa-circle"></i>Adicionar
                                comunicado</a></li>
                        <li><a href="<?php echo e(route('admin.notice')); ?>"><i class="far fa-circle"></i>Listar comunicados</a>
                        </li>
                    </ul>
                </li>


                <li class="sidebar-title">
                    Contabilidade
                </li>
                <li>
                    <a href="#"><i data-feather="users"></i>Pagamentos<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                                            
                        <li><a href="<?php echo e(route('admin.list.feegroups')); ?>"><i class="far fa-circle"></i>Grupo de Taxas</a></li>
                        <li><a href="<?php echo e(route('admin.list.feetypes')); ?>"><i class="far fa-circle"></i>Tipos de Taxas</a></li>
                        <li><a href="<?php echo e(route('admin.fee.feesdiscount')); ?>"><i class="far fa-circle"></i>Desconto nas Taxas</a></li>
                        <li><a href="<?php echo e(route('admin.list.feemaster')); ?>"><i class="far fa-circle"></i>Plano de Taxas</a></li>
                        <li><a href="<?php echo e(route('admin.fee.collectfee')); ?>"><i class="far fa-circle"></i>Cobranças</a></li>
                        
                    </ul>
                </li>


                <li class="sidebar-title">
                    Biblioteca digital
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Categoria<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.category')); ?>"><i class="far fa-circle"></i>Adiciconar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.categories')); ?>"><i class="far fa-circle"></i>Listar</a>
                        </li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Livros<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.book')); ?>"><i class="far fa-circle"></i>Adicionar</a></li>
                        <li><a href="<?php echo e(route('admin.list.books')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li>
                    <a href="#"><i data-feather="book"></i>Capítulos de livro<i
                            class="fas fa-arrow-right dropdown-icon"></i></a>
                    <ul class="">
                        <li><a href="<?php echo e(route('admin.add.chapter')); ?>"><i class="far fa-circle"></i>Adicionar</a>
                        </li>
                        <li><a href="<?php echo e(route('admin.list.chapters')); ?>"><i class="far fa-circle"></i>Listar</a></li>
                    </ul>
                </li>
                <li class="sidebar-title">
                    Outros
                </li>
                <li>
                    <a href="<?php echo e(route('admin.report')); ?>"><i data-feather="file-text"></i>Relatório trimestral
                        (D)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.combine.report')); ?>"><i data-feather="file-text"></i>Relatório
                        trimestral (T)</a>
                </li>

                <li>
                    <a href="<?php echo e(route('admin.subject.report')); ?>"><i data-feather="file-text"></i>Relatório final
                        (D)</a>
                </li>
                <li class="sidebar-title">
                    Configurações
                </li>
                <li>
                    <a href="<?php echo e(route('admin.permission')); ?>"><i data-feather="file-text"></i>Permissões</a>
                </li>
            <?php endif; ?>
            <li>
                <a href="#" wire:click="logout"><i data-feather="log-out"></i>Sair</a>
            </li>
        </ul>
    </div>
</div>
<?php /**PATH /home/1165120.cloudwaysapps.com/ttmjqktapb/public_html/resources/views/livewire/admin/inc/sidebar.blade.php ENDPATH**/ ?>
